diff src/spell.c @ 20760:813b9a7064a4 v8.2.0932

patch 8.2.0932: missspelling spelllang Commit: https://github.com/vim/vim/commit/f154f3ab2c1eea67afc20140c580ad003752dc72 Author: Bram Moolenaar <Bram@vim.org> Date: Mon Jun 8 18:54:49 2020 +0200 patch 8.2.0932: missspelling spelllang Problem: Missspelling spelllang. Solution: Add an "l". (Dominique Pelle)
author Bram Moolenaar <Bram@vim.org>
date Mon, 08 Jun 2020 19:00:04 +0200
parents d571231175b4
children 90b96fa35e4b
line wrap: on
line diff
--- a/src/spell.c
+++ b/src/spell.c
@@ -2002,7 +2002,7 @@ did_set_spelllang(win_T *wp)
 	region = NULL;
 	len = (int)STRLEN(lang);
 
-	if (!valid_spellang(lang))
+	if (!valid_spelllang(lang))
 	    continue;
 
 	if (STRCMP(lang, "cjk") == 0)
@@ -4303,10 +4303,10 @@ expand_spelling(
 }
 
 /*
  * Return TRUE if "val" is a valid 'spellang' value.
  */
     int
-valid_spellang(char_u *val)
+valid_spelllang(char_u *val)
 {
     return valid_name(val, ".-_,@");
 }
@@ -4303,10 +4303,10 @@ expand_spelling(
 
 /*
- * Return TRUE if "val" is a valid 'spellang' value.
+ * Return TRUE if "val" is a valid 'spelllang' value.
  */
     int